/*
 * poly.h
 *
 * Polygon drawing and clipping header file
 */

#ifndef INCLUDED_POLY_H
#define INCLUDED_POLY_H

#include "types.h"


/*****************************************************************************
 Configuration
*****************************************************************************/

#define MAX_SPANS   2048    // maximum number of spans per polygon


/*****************************************************************************
 Polygon Data Structures

 These data structures are related to the concept of a polygon.
*****************************************************************************/

/*
 * 2D Vertex
 *
 * Each vertex is relative to the polygon itself. The coordinates are mapped
 * to frame buffer coordinates by adding X and Y offsets.
 */

typedef struct
{
    INT32   x;
    INT32   y;
} VERTEX2D;

/*
 * Span Definition
 */

typedef struct
{
    UINT32  xend;
    UINT32  xstart;
} SPAN;


/*****************************************************************************
 Functions
*****************************************************************************/

extern void     Polygon_DrawSolid(INT32, INT32, UINT8, UINT32, UINT8 *,
                                  VERTEX2D *, UINT32);


#endif  // INCLUDED_POLY_H
